#
# spec file for package perl-HTTP-BrowserDetect
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name HTTP-BrowserDetect
Name:           perl-HTTP-BrowserDetect
Version:        3.400.0
Release:        2.2
%define cpan_version 3.40
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Determine Web browser, version, and platform from an HTTP user agent string
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(JSON::PP) >= 4.04
BuildRequires:  perl(List::Util) >= 1.49
BuildRequires:  perl(Path::Tiny)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::NoWarnings)
BuildRequires:  perl(Test::Warnings)
Provides:       perl(HTTP::BrowserDetect) = 3.400.0
%undefine       __perllib_provides
%{perl_requires}

%description
The HTTP::BrowserDetect object does a number of tests on an HTTP user agent
string. The results of these tests are available via methods of the object.

For an online demonstration of this module's parsing, you can check out
https://www.browserdetect.org/

This module was originally based upon the JavaScript browser detection code
available at
http://www.mozilla.org/docs/web-developer/sniffer/browser_type.html.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTORS examples README.md TODO
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Oct 20 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.40
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.40      2023-10-19 16:23:54Z
  - Remove Hash::Merge (GH#205) (Olaf Alders)
* Sat Sep  9 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.39
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.39      2023-09-08 13:07:26Z
  - Match iOS by `iPod|iPhone|iPad` with word boundary (GH#203) (sakakibear)
* Sat Mar  4 2023 Tina Müller <timueller+perl@suse.de>
- updated to 3.38
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.38      2023-03-03 21:37:52Z
  - Detect Yandex Browser (GH#201) (altblue)
  - Detect some "Meta" apps (GH#199) (altblue)
  - Detect Instagram (GH#200) (altblue)
* Wed Sep 28 2022 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 3.37
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.37      2022-09-15 16:39:38Z
  - Add Chromecast detection (GH#195) (Yasuharu Iida)
* Fri Sep  2 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.36
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.36      2022-08-31 22:36:10Z
  - Detect Firefox for iOS (GH#194) (altblue)
* Wed Oct 20 2021 Tina Müller <tina.mueller@suse.com>
- Add precious.toml to skip_doc
* Wed Oct 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.35
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.35      2021-10-19 15:53:52Z
  - Add Samsung as a detected browser (GH#192) (Olaf Alders)
* Wed Aug  4 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.34
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.34      2021-08-03 20:09:33Z
  - Fix modern UCBrowser detection (GH#189) (konstantin-pustovalov-qs)
  - Switch from Test::FailWarnings to Test::Warnings (GH#190) (Olaf Alders
* Thu Jul 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.33
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.33      2021-07-21 14:38:49Z
  - Yahoo iOS App as not a robot (GH#188) (Yasuharu Iida)
  3.32      2021-07-20 21:13:13Z
  - add headlesschrome as robot (GH#187) (Ilya Rassadin)
  - Tidy imports (GH#184) (Olaf Alders)
* Thu Jul 30 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.31
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.31      2020-07-29 14:29:55Z
  - Replace last use of "vars" with "our" (GH#182) (James Raspass)
* Tue Jul 21 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.30
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.30      2020-07-20 15:45:22Z
  - Fix MS Edge browser_beta capturing (GH#181) (moti)
* Wed Jul 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.29
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.29      2020-07-14 15:36:33Z
  - Fix MS Edge detections (GH#180) (moti)
* Sat Jul 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.28
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.28      2020-07-10 14:59:08Z
  - Fix typo for 'wv' (GH#178) (Jon Jensen
* Thu Apr 16 2020 <timueller+perl@suse.de>
- updated to 3.27
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.27      2020-04-15 16:18:20Z
  - Improve detection for MS Edge (GH#177) (Zak B. Elep)
* Tue Mar 17 2020 <timueller+perl@suse.de>
- updated to 3.26
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.26      2020-03-16 21:54:21Z
  - Fix Microsoft Edge detection (GH#176) (Mahdi Zarei)
* Thu Nov 21 2019 <timueller+perl@suse.de>
- updated to 3.25
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.25      2019-11-20 14:11:51Z
  - Remove a near duplicate regex (GH#171) (Gregory Oschwald)
* Fri Nov  1 2019 <timueller+perl@suse.de>
- updated to 3.24
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.24      2019-10-31 17:48:35Z
  - Bump JSON::PP to 4.04. Fixes #169 (GH#170) (Olaf Alders)
  - Remove links to AnnoCPAN (GH#168) (Petr)
  - Fixed pod error as reported by CPANTS. (GH#166) (Mohammad S Anwar)
  - Fix bad syntax in SYNOPSIS (reported by John Blumel) (GH#163) (Olaf Alders)
* Fri Apr  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.23
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.23      2019-04-04 19:26:18Z
  - Add BingPreview to bot checker (GH#162) (James Waters)
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.22
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.22      2019-03-07 15:11:01Z
  - Add a u2f() method (GH#161) (Patrick Cronin and Olaf Alders)
  - Don't warn on fake UA strings. (GH#160) (Olaf Alders)
* Tue Feb  5 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.21
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.21      2019-02-05 01:50:40Z
  - Faster edge test (GH#158) (Marco Fontani)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.20
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.20      2018-12-04 18:37:08Z
  - Fix minor version warning (GH#152) (Olaf Alders)
  - Fix a typo in the POD. (GH#149) (gregor herrmann)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.19
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.19      2018-10-11 16:04:00Z
  - Detect ltx71 bot (GH#147) (Olaf Alders)
  - test for "ltx71" robot (GH#113) (Alexandr Ciornii)
  - Stop clobbering useragent tests (GH#146) (Olaf Alders)
  - Removed +x bit from package and test script. (GH#145) (Mohammad S Anwar)
  - Fixed minor typo in the pod. (GH#144) (Mohammad S Anwar)
  3.18      2018-10-10 15:01:41Z
  - Define exceptions for ROBOT_FRAGMENTS (fix for #136) (GH#140) (Renee)
  - Add another test for SeznamBot. UA string was provided in #131. (GH#142) (Renee)
  - Fix (GH#119): add researchscan.comsys.rwth-aachen.de as a robot (GH#141) (Renee)
  3.17      2018-10-03 02:02:53Z
  - Fix of 'wv' is not language + the new webview property (GH#139) (Perlover)
  - Patch for tests (GH#138) (Perlover)
* Fri Dec 15 2017 coolo@suse.com
- updated to 3.16
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.16      2017-12-14 17:38:34Z
  - Fixes detection for bots added in 3.15
  - Adds all_robot_ids() method
* Thu Dec 14 2017 coolo@suse.com
- updated to 3.15
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.15      2017-12-13 03:25:42Z
  - Adds browserdetect.org to documentation
  - Adds more bots to robot detection
  - Adds robot_id(), which is currently in beta
* Sat May 28 2016 coolo@suse.com
- updated to 3.14
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.14 2016-05-25 11:44:10 America/Toronto
  - Slightly refactor the detection of several browsers that
    identify as Mozilla initially (andrewmoise)
  - Start detecting UCBrowser much more accurately (device, version,
    and detect some cases which were misidentified as something else
    previously) (andrewmoise)
  - Detect more possibilities for Kindle Fire in Android model
    ("Kindle Fire in addition to "KF.*") (andrewmoise)
  - Detect more possibilities for Kindle Fire, and try to set tests
    appropriate to whatever the device is configured to be
    (andrewmoise)
* Mon May 23 2016 coolo@suse.com
- updated to 3.13
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.13 2016-05-09 11:10:44 America/Toronto
  - Start detecting Brew OS (andrewmoise)
  - Fix detecting Netfront as Netscape in some cases (andrewmoise)
  - Start recognizing Teleca as an alias for Obigo (andrewmoise)
  - Start detecting versions of Teleca / Obigo (andrewmoise)
  - Note in documentation that 'wap' doesn't mean WAP only
    (andrewmoise)
  - Start detecting Polaris mobile browser (andrewmoise)
  3.12 2016-05-05 08:59:46 America/Toronto
  - Start detecting a few robots we weren't detecting before
    ('verify' or 'analyze' in the name, or +https: beginning
    the URL) (andrewmoise)
  - Stop including the version in robot_string() in some
    cases (andrewmoise)
  - Start returning undef instead of 0 for robot() if there's
    no robot (andrewmoise)
  - Fix _version() documentation for robot, os, and version not
    to make formatting garbage in the output, and to be
    consistent (andrewmoise)
* Thu May  5 2016 coolo@suse.com
- updated to 3.11
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.11 2016-05-04 20:32:47 America/Toronto
  - Add a test for Kindle Fire (andrewmoise)
* Mon Apr  4 2016 coolo@suse.com
- updated to 3.10
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.10 2016-03-29 22:15:35 America/Toronto
  - Big change: Add robot version detection, distinct from browser
    version (first cut) (andrewmoise)
  - Add browsers: Pubsub (Safari RSS reader), ADM (Android Download
    Manager), ImageSearcherPro (iOS app) (andrewmoise)
  - Add robots: Google favicon, malware/shellcode, phplib,
    Verisign IPS agent, Nutch, thumbtack-thunderdome (andrewmoise)
  - Distinguish Bingbot from MSNbot (andrewmoise)
  - Only detect wget based on the beginning of the user-agent
    (andrewmoise)
  - Misc fixes to test support scripts (andrewmoise)
  - Add Kindle Fire (andrewmoise)
  - Detect curl by matching /^curl/ as well as /libcurl/
    (andrewmoise)
  - Remove webcrawler robot test (it triggers on too many distinct
    robots which all include "webcrawler") (andrewmoise)
* Tue Mar  8 2016 coolo@suse.com
- updated to 3.00
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  3.00 2016-02-29 22:57:45 America/Toronto
  - Make "mobile" false when "tablet" is true.  This is a breaking change and
    has triggered a major version bump. (andrewmoise)
* Sun Feb  7 2016 coolo@suse.com
- updated to 2.08
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.08 2016-01-29 21:56:29 America/Toronto
  - Brave browser detection added (Nicolas Doye)
* Fri Nov 20 2015 coolo@suse.com
- updated to 2.07
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.07 2015-11-18 23:52:07 America/Toronto
  - Strip off anything Google Translate adds to UserAgent before parsing
    (Marco Fontani)
* Mon Nov 16 2015 coolo@suse.com
- updated to 2.06
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.06 2015-11-15 10:59:30 America/Toronto
  - Detect more Edge versions (Marco Fontani)
* Sat Aug  1 2015 coolo@suse.com
- updated to 2.05
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.05 2015-07-29 12:36:01 America/Toronto
  - Add Microsoft Windowns 10/Windows Phone 10 Edge Browser (Atsushi Kato)
* Sat Jun 27 2015 coolo@suse.com
- updated to 2.04
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.04 2015-06-24 23:26:28 America/Toronto
  - Fix test failures on Perl 5.8
* Sun Jun 21 2015 coolo@suse.com
- updated to 2.03
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.03 2015-06-19 09:59:45 America/Toronto
  - Add win8_1 method (Daniel Stadie)
* Thu Jun 18 2015 coolo@suse.com
- updated to 2.02
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.02 2015-06-17 18:18:17 America/Toronto
  - Default to using an empty string if an undef UA is provided (ben hengst)
* Sat Apr 25 2015 coolo@suse.com
- updated to 2.01
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.01 2015-04-24 23:05:13 America/Toronto
  - Handle "CriOS" entries correctly (andrewmoise)
  - Only detect java when no browser is detected, and make UCBrowser a
    detected browser (andrewmoise)
  - Detect "tablet" on Kindle Fire (and Chrome on Android tablets in general)
    (andrewmoise)
  - Distinguish Android tablets in device_string (andrewmoise)
  - Handle CriOS, rubylib, golib, and Dalvik (andrewmoise)
  - Detect "Mobilesafari/" as Mobile Safari (andrewmoise)
  - Detect "Windows 2000" as Win2k (andrewmoise)
  - Only detect NCR Unix on word boundary (andrewmoise)
  - Try tighter detection of robot names based on fragments (andrewmoise)
  - Fix java detection to be more strict (andrewmoise)
  - Fix up Android tablet detection (andrewmoise)
  - Add proper detection for old Windows versions in Opera (andrewmoise)
  - Add apache http client detection (andrewmoise)
  - Fix detection of SCO Unix to trigger fewer false positives (andrewmoise)
  - Correct detection of (most) robots based on "+http://blah" (andrewmoise)
* Tue Apr 14 2015 coolo@suse.com
- updated to 2.00
  see /usr/share/doc/packages/perl-HTTP-BrowserDetect/Changes
  2.00 2015-03-30 21:46:25 America/Toronto
  - Standardize interface:
    browser         ()
    device     X    _string()
    engine          _version(), _major(), _minor(), _beta()
    os
    robot
    (andrewmoise)
  - Add Galeon, Seamonkey, and Epiphany as specifically detected
    browsers (andrewmoise)
  - Some internal changes that make things simpler and faster
    (andrewmoise)
  - Remove the $check argument (e.g. $ua->beta('.45') to check
    whether the beta version is ".45") (andrewmoise)
  - Update and reorganize documentation (andrewmoise)
  - Breaking Change: remove deprecated user_agent($arg) usage.
    This is the reason for the major version bump.
  1.78 2015-03-17 22:43:27 America/Toronto
  - Reorganize documentation (andrewmoise)
  - Make java a robot with the other libs and tools (andrewmoise)
  - Add a "lib" test to detect libs and tools (andrewmoise)
  - Add AppleCoreMedia (andrewmoise)
  - Make Blackberry stop setting Safari tests (andrewmoise)
  - Make Android stop setting Linux tests (andrewmoise)
  - Implement much more engine detection and engine version
    detection (andrewmoise)
* Mon Mar  9 2015 joschibrauchle@gmx.de
- update to version 1.77
- changes since version 1.55:
  * Switch to using strings for version numbers (andrewmoise)
  * Adds BrowseX and Silk detection (andrewmoise)
  * Makes detection of Obigo more consistent (andrewmoise)
  * Encourage use of public_* and engine_* over version(), major() and
    minor().
  * Speed optimizations (andrewmoise)
  * Fix warnings on "Safari/12x.x (andrewmoise)
  * Adds detection for Chrome OS (Douglas Christopher Wilson)
  * Adds detection for Majestic-12 bot (Douglas Christopher Wilson)
  * Adds minimum Perl version
  * dzil tweaks to make CPANTS happier
  * Remove File::Slurp from tests in favour of Path::Tiny
  * Fixes warnings on "frakenagent" (Douglas Christopher Wilson)
  * Add new UA tests & avoid false positive Sun match on Samsung (Jon Jensen)
  * Adds detection for BlackBerry 10 devices (Douglas Christopher Wilson)
  * Adds Yandex & Ahrefs bots (Perlover)
  * Adds detection for tablet Firefox OS (Douglas Christopher Wilson)
  * Adds detection for IE Compatibility View (Douglas Christopher Wilson)
  * Adds os_version for FireFox in OS X (Hao Wu)
  * Adds detection for Opera 15+ (Douglas Christopher Wilson)
  * Adds detection for Internet Explorer 11 (Douglas Christopher Wilson)
  * Adds detection for Windows 8.1 (Douglas Christopher Wilson)
  * Returns explicit undef more consistently (David Ihnen)
  * Reverts a commit that was causing a test to fail when a warning about
    File::Slurp was detected
  * Fixes bug where "Linux" rather than "Android" was returned as os_string
    for Android devices.
  * Revert 1.57's behaviour of returning a robot name in browser_string.
  * Fix bug where OS X identied as just Mac in os_string.
  * Add linkchecker, YandexImages and archive.org_bot bots.
  * Add undocumented os_version() for OS X, winPhone, Android, iOS, Firefox
    OS.
  * Break up parsing into smaller chunks.
  * Return better names for Googlebot News, Images and Video.
  * Fix bug where Yahoo! Slurp reported as Firefox.
  * Make internals a little less quirky.
  * Stop returning explicit undef for browser_string and os_string.  (Why
    would you ever call these in list context?)
  * Return name of robot for browser_string when browser is, in fact, a bot.
    Previous behaviour was to return undef or something just really wrong.
  * Adds experimental and undocumented robot_name method.
* Wed Jul 24 2013 lnt-sysadmin@lists.lrz.de
- update to version 1.55 (bugfix release)
  * Adds detection of BlackBerry Playbook
* Wed Jul 17 2013 lnt-sysadmin@lists.lrz.de
- update to version 1.52
  * Adds detection of iOS, Windows Phone, Windows 8, IE 8/9
  * New BuildRequires: Test-Most, Test-NoWarnings, Test-FailWarnings
* Sun May  1 2011 coolo@opensuse.org
- initial package 1.22
  * created by cpanspec 1.78.04
